unofficial mirror of bug-gnu-emacs@gnu.org 
 help / color / mirror / code / Atom feed
* bug#37584: [PATCH] Quadruple term-buffer-maximum-size
@ 2019-10-02 13:52 Stefan Kangas
  2019-10-07  4:05 ` Lars Ingebrigtsen
  0 siblings, 1 reply; 3+ messages in thread
From: Stefan Kangas @ 2019-10-02 13:52 UTC (permalink / raw)
  To: 37584

[-- Attachment #1: Type: text/plain, Size: 333 bytes --]

term-buffer-maximum-size has been 2048 since 1997:

commit ce0ba762d737cd36b20513cd6d9540643524c581
Author: Richard M. Stallman <rms@gnu.org>
Date:   Wed Apr 2 03:46:39 1997 +0000

I think we have more memory nowadays, and a more reasonable default
would probably be 8192.

Any objections to doing this?

Best regards,
Stefan Kangas

[-- Attachment #2: 0001-Quadruple-term-buffer-maximum-size.patch --]
[-- Type: application/octet-stream, Size: 1768 bytes --]

From 84a4bc1f9ff288738b3ccc565668c1bb0c83384f Mon Sep 17 00:00:00 2001
From: Stefan Kangas <stefankangas@gmail.com>
Date: Wed, 2 Oct 2019 15:50:54 +0200
Subject: [PATCH] Quadruple term-buffer-maximum-size

* lisp/term.el (term-buffer-maximum-size): Quadruple to 8192.
---
 lisp/term.el | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/lisp/term.el b/lisp/term.el
index 43239d9b6c..127893fe80 100644
--- a/lisp/term.el
+++ b/lisp/term.el
@@ -23,7 +23,7 @@
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs.  If not, see <https://www.gnu.org/licenses/>.
 
-;; Marck 13 2001
+;; March 13 2001
 ;; Fixes for CJK support by Yong Lu <lyongu@yahoo.com>.
 
 ;; Dir/Hostname tracking and ANSI colorization by
@@ -102,9 +102,8 @@
 ;;
 ;;             ----------------------------------------
 ;;
 ;;  With the term-buffer-maximum-size you can finally decide how many
 ;; scrollback lines to keep: its default is 2048 but you can change it as
 ;; usual.
 ;;
 ;;             ----------------------------------------
 ;;
@@ -800,14 +799,15 @@ term-color-white
   "Face used to render white color code."
   :group 'term)
 
-;; Inspiration came from comint.el -mm
-(defcustom term-buffer-maximum-size 2048
+(defcustom term-buffer-maximum-size 8192
   "The maximum size in lines for term buffers.
 Term buffers are truncated from the top to be no greater than this number.
 Notice that a setting of 0 means \"don't truncate anything\".  This variable
 is buffer-local."
   :group 'term
-  :type 'integer)
+  :type 'integer
+  :version "27.1")
+
 \f
 ;; Set up term-raw-map, etc.
 
@@ -102,9 +102,8 @@
 ;;             ----------------------------------------
 ;;
-;;  With the term-buffer-maximum-size you can finally decide how many
-;; scrollback lines to keep: its default is 2048 but you can change it as
-;; usual.
+;;  With the term-buffer-maximum-size you can decide how many
+;; scrollback lines to keep: its default is 8192.
 ;;
 ;;             ----------------------------------------
-- 
2.23.0


^ permalink raw reply related	[flat|nested] 3+ messages in thread

* bug#37584: [PATCH] Quadruple term-buffer-maximum-size
  2019-10-02 13:52 bug#37584: [PATCH] Quadruple term-buffer-maximum-size Stefan Kangas
@ 2019-10-07  4:05 ` Lars Ingebrigtsen
  2019-10-07 10:19   ` Stefan Kangas
  0 siblings, 1 reply; 3+ messages in thread
From: Lars Ingebrigtsen @ 2019-10-07  4:05 UTC (permalink / raw)
  To: Stefan Kangas; +Cc: 37584

Stefan Kangas <stefan@marxist.se> writes:

> I think we have more memory nowadays, and a more reasonable default
> would probably be 8192.

Makes sense to me.

-- 
(domestic pets only, the antidote for overdose, milk.)
   bloggy blog: http://lars.ingebrigtsen.no





^ permalink raw reply	[flat|nested] 3+ messages in thread

* bug#37584: [PATCH] Quadruple term-buffer-maximum-size
  2019-10-07  4:05 ` Lars Ingebrigtsen
@ 2019-10-07 10:19   ` Stefan Kangas
  0 siblings, 0 replies; 3+ messages in thread
From: Stefan Kangas @ 2019-10-07 10:19 UTC (permalink / raw)
  To: Lars Ingebrigtsen; +Cc: 37584-done

Lars Ingebrigtsen <larsi@gnus.org> writes:

> > I think we have more memory nowadays, and a more reasonable default
> > would probably be 8192.
>
> Makes sense to me.

Thanks, pushed to master as commit 130b1321ed.

Best regards,
Stefan Kangas





^ permalink raw reply	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2019-10-07 10:19 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2019-10-02 13:52 bug#37584: [PATCH] Quadruple term-buffer-maximum-size Stefan Kangas
2019-10-07  4:05 ` Lars Ingebrigtsen
2019-10-07 10:19   ` Stefan Kangas

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/emacs.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).